Sidney Phillips : New instructions and recent changes - pubs for sale in England and Wales - stop press.
Author: Sidney Phillips
Description: UK based licensed business agents. New instructions on pubs for sale and other licensed premises including hotels and restaurants.
Keywords: new instructions on pubs for sale, uk, freehold, leasehold, public houses, inns, rural, urban, city centre, sales

accessibility | skip nav
Home | Login | Register
08454 585 900
Search for information
or
Property Quick Search

# New instructions and recent changes

Show properties listed within the last

You can view all available properties in the Businesses for sale section.

West Glamorgan
info
Ref: 39212
add to shortlist

- DILLWYN ARMS BRYNHYFRYD SWANSEA
- Suburban City Location
- Prominent "crossroads" pub
- Two good bars
- Three bedroom owners accommodation
- Trade garden and car park
- EPC rating D

Freehold Offers around £150,000
Bath & N. E Somerset
info
Ref: 40581
add to shortlist

- BATH FREE HOUSE
- In village on edge of City.
- Interconnecting Bars Alley
- 4 Bedroom Flat Yard
- 17 years in present ownership
- No EPC as Grade II Listed

Leasehold £19,500
Powys
info
Ref: 35349
add to shortlist

- STAR INN TALYBONT ON USK BRECON
- Canalside Brecon Beacons Pub
- Cult 'real ale' venue
- Centuries old property
- 3 interconnecting bars
- 2 e/s letting rooms. Owners flat
- Riverside gardens

Freehold Offers around £295,000
Herefordshire
info
Ref: 39914
add to shortlist

- HEREFORDSHIRE
- Georgian Manor Country House Hotel
- 2 lounges/bars: Restaurant (70)
- Marquee (130): 20 en suite bedrooms
- 11 staff rooms: Conference facility
- Swimming pool: Gardens & vineyard
- T/O £534,000 per annum

Freehold Offers around £1,250,000
Worcestershire
info
Ref: 38012
add to shortlist

- PJ'S MARKET PLACE EVESHAM
- Central lock up premises
- Open plan bar area - 2,500 sq ft
- Catering kitchen
- Licensed/office/retail use
- Currently closed
- EPC Rating D

Leasehold Offers around
Essex
info
Ref: 38119
add to shortlist

- ESSEX
- Community pub next to station
- Traditional public bar (40)
- Large trade garden & car park
- Spacious 4 bed owners accommodation
- Additional 1 bed flat
- Potential to add food & lettings

Leasehold £59,995
Worcestershire
info
Ref: 38951
add to shortlist

- BROADWATERS INN KIDDERMINSTER
- Edge of Worcestershire town
- Purpose built suburban public house
- Two bars
- 3/4 bedroom owners accommodation
- Trade garden and car park
- EPC rating D

Freehold Offers around £195,000
Mid Glamorgan
info
Ref: 30832
add to shortlist

- SOUTH WALES- NR BRIDGEND
- Centuries old pub and restaurant
- 3 section open plan bar areas (120)
- High quality owners accommodation
- Gardens and car parking
- T/O £140,000 p.a (45% food/55% wet)
- EPC rating C

Freehold Offers around £260,000
Suffolk
info
Ref: 40560
add to shortlist

- SUFFOLK - COUNTRYSIDE LOCATION
- Rural village of Forward Green
- Front bar (10) & dining area (24)
- Restaurant/function room (60)
- 1 bedroom owners accommodation
- Large car park (35) & patio area
- A popular venue currently closed

Leasehold £35,000
North Yorkshire
info
Ref: 40102
add to shortlist

- NORTH LINCOLNSHIRE
- Popular community pub
- Snug public & back bars
- Outbuilding development opportunity
- Patio beer garden
- 2 Bedroom private accommodation
- EPC Rating C

Freehold £230,000
West Midlands
info
Ref: 36932
add to shortlist

- WEST MIDLANDS/BLACK COUNTRY
- Award winning real ale venue
- Two bars & feature restaurant
- Three bedroom owners accommodation
- Enclosed garden
- T/O £473,000 pa net of VAT
- EPC rating C

Freehold Offers around £499,000
Worcestershire
info
Ref: 40036
add to shortlist

- WORCESTERSHIRE
- Village pub set in 0.52 of an acre
- Lounge bar/games area/restaurant
- Three bedroom owners accommodation
- Gardens and car parking
- For sale after 24 years
- EPC rating D

Freehold Offers around £670,000
Carmarthenshire
info
Ref: 36974
add to shortlist

- CARMARTHENSHIRE
- Village centre public house
- 2 section bar/lounge & restaurant
- Three bedroom owners accommodation
- Enclosed beer patio & car park
- Building plot for bookmakers & flat
- EPC rating G

Freehold Offers around £165,000
Caerphilly
info
Ref: 40294
add to shortlist

- BLACKWOOD
- Recently refurbished hotel
- Twelve bedrooms
- Scope to increase trade
- Development potential (STPP)
- Excellent reception rooms
- One bedroom private flat

Freehold £299,500
Herefordshire
info
Ref: 38709
add to shortlist

- HEREFORD
- Cathedral City Centre Freehouse
- Venue bar in pedestrianised area
- Ground/1st floor contemporary bars
- Manager's flat. Trade garden
- Separate two bedroom house
- Currently closed. EPC Rating D

Freehold Offers around £295,000
Middlesborough
info
Ref: 39439
add to shortlist

- MIDDLESBROUGH
- Prominent outlet on shopping street
- Close to transport interchange
- Open plan bar FF catering kitchen
- 2 bedroom flat to develop
- Possible alternative uses STPP
- EPC rating E

Freehold Offers invited
Bath & N. E Somerset
info
Ref: 40267
add to shortlist

- SOMERSET
- Wet Sales Only. Free House
- Character flagstone & woodwork
- Spacious Three Bedroom Flat
- Alley. C/P. Garden. Patio
- EPC rated D

Leasehold £65,000
East Sussex
info
Ref: 38641
add to shortlist

- EAST SUSSEX - MAIN ROAD LOCATION
- Affluent village location on A21
- Substantial Georgian property
- Bar & restaurant (80-100)
- Garden (40) patio (36) & car park
- Adaptable 5 bedroom accommodation
- Potential for 3 additional lets

Leasehold £80,000
Gloucestershire
info
Ref: 40233
add to shortlist

- KING'S HEAD WITHINGTON CHELTENHAM
- Undeveloped Cotswold Stone Inn
- Same family hands 103 years
- 2 bars. 3/5 bedrooms
- Car park. Large garden
- Circa 1.5 acres
- Currently closed. EPC Rating E

Freehold £325,000
Somerset
info
Ref: 29317
add to shortlist

- SOMERSET DORSET VILLAGE BORDER
- Free House in centre of village
- 2 Bars 1 incorporating Skittles
- Flat with 2 E/S Beds
- Car Park & Terrace
- Retiring owners 15 yrs occupation
- EPC Rating D

Freehold £375,000
Herefordshire
info
Ref: 40410
add to shortlist

- HEREFORDSHIRE
- Historic Georgian Coaching Inn
- Set in an attractive rural location
- Large bar/restaurant/Function room
- 3 bed owners flat. 2 cottages
- Garden & parking(set in 0.64 acres)
- EPC Rating E

Freehold Offers around £375,000
Bedfordshire
info
Ref: 40220
add to shortlist

- BEDS - NORTH BEDFORDSHIRE VILLAGE
- Affluent North Bedfordshire village
- Well-presented detached pub
- Two bars (32) & restaurant (38)
- Large garden & car park
- Held on private free-of-tie lease
- Destination food-led business

Leasehold Offers over £50,000
Somerset
info
Ref: 38297
add to shortlist

- TAUNTON
- Highly Acclaimed Village Pub
- Connecting Bars & Dining Rooms
- Mature Gdns/Parking. Owners' Flat
- Food led trade-net sales £300k
- Somerset's Pub of the Year 2012/13
- EPC Rating D

Leasehold £65,000
Worcestershire
info
Ref: 40545
add to shortlist

- DROITWICH WORCESTERSHIRE
- Popular Worcestershire Spa Town
- Grade II Listed Central Pub
- Enclosed Trade Garden & Car Park
- Building in good condition
- Wet sales with scope for food
- EPC Rating E

Freehold Offers around £345,000
Leasehold Offers around £25,000
Ceredigion
info
Ref: 39562
add to shortlist

- CEREDIGION
- Teifi Valley roadside freehouse
- Excellent open plan trading areas
- Bar restaurant games room
- Function room 6 letting bedrooms
- 2 bed private flat. Trade garden
- Car park. EPC Rating E

Freehold Offers around £375,500
Kent
info
Ref: 40474
add to shortlist

- KENT - HIGHLY POPULATED NORTHFLEET
- Located in village of Northfleet
- Sizeable 3 storey public house
- Ground floor bar (14) & pool area
- 9 letting bedrooms
- Wet led community business
- Suitable for alternative use (STPP)

Freehold £450,000
Somerset
info
Ref: 40407
add to shortlist

- SOMERSET
- Free House on edge of town
- Two Bars
- Enclosed Garden large Car Park
- Two Bedroom Flat
- Turnover in region of £200,000
- No EPC as Grade II Listed

Leasehold £50,000
Gloucestershire
info
Ref: 40566
add to shortlist

- OLD RESTORATION CHELTENHAM
- The oldest pub in Cheltenham
- C17 "black & white" free house
- Four section open plan bar areas
- Three bed owners accommodation
- Separate two bed flat
- Net T/O £454,324 pa: EPC rating D

Leasehold Offers around £145,000
Northumberland
info
Ref: 38791
add to shortlist

- NORTHUMBERLAND
- Pub in beautiful N'land village
- Dest'n food-house bar diner(50)
- 5 letting rooms. Car park(20)
- 3 bedroom private accommodation
- Good prof further scope to increase
- GRADE II LISTED

Freehold Offers around £530,000
Neath Port Talbot
info
Ref: 38310
add to shortlist

- WEST GLAMORGAN
- Country Inn & Function Venue
- Set in 2.64 acres. Gardens/parking
- Lounge bar & two section restaurant
- Function room & meeting room
- 4 letting bedrooms. 3 bedroom flat
- T/O £375,000 pa net. EPC Rating D

Freehold £650,000